@@ -42,6 +42,7 @@ from pyhilo.const import (
     FB_INSTALL_HEADERS,
     FB_INSTALL_HOSTNAME,
     FB_SDK_VERSION,
+    HILO_READING_TYPES,
     LOG,
     REQUEST_RETRY,
     SUBSCRIPTION_KEY,
@@ -89,6 +90,7 @@ class API:
         self.websocket: WebsocketClient
         self._username: str
         self._refresh_token_callbacks: list[Callable[..., Any]] = []
+        self.log_traces: bool = False
 
     @property
     def headers(self) -> dict[str, Any]:
@@ -114,8 +116,10 @@ class API:
         provided_refresh_token: Union[str, None] = None,
         request_retries: int = REQUEST_RETRY,
         state_yaml: str = DEFAULT_STATE_FILE,
+        log_traces: bool = False,
     ) -> API:
         api = cls(session=session, request_retries=request_retries)
+        api.log_traces = log_traces
         api._state_yaml = state_yaml
         api.state = get_state(state_yaml)
         if provided_refresh_token:
@@ -139,6 +143,7 @@ class API:
         session: ClientSession,
         request_retries: int = REQUEST_RETRY,
         state_yaml: str = DEFAULT_STATE_FILE,
+        log_traces: bool = False,
     ) -> API:
         """Get an authenticated API object from a username and password.
         :param username: the username
@@ -154,6 +159,7 @@ class API:
         :rtype: :meth:`pyhilo.api.API`
         """
         api = cls(session=session, request_retries=request_retries)
+        api.log_traces = log_traces
         api._username = username
         api._state_yaml = state_yaml
         api.state = get_state(state_yaml)
@@ -181,7 +187,9 @@ class API:
         await api._async_post_init()
         return api
 
-    def dev_atts(self, attribute: str) -> Union[DeviceAttribute, None]:
+    def dev_atts(
+        self, attribute: str, value_type: Union[str, None] = None
+    ) -> Union[DeviceAttribute, None]:
         """Returns the DeviceAttribute object by attribute, camel case or not.
 
         :return: An object representing a device attribute.
@@ -193,7 +201,9 @@ class API:
                 for x in self.device_attributes
                 if x.hilo_attribute == attribute or x.attr == attribute
             ),
-            None,
+            DeviceAttribute(attribute, HILO_READING_TYPES.get(value_type, ""))
+            if value_type
+            else None,
         )
 
     def _get_fid_state(self) -> bool:
@@ -357,8 +367,9 @@ class API:
         kwargs["headers"]["Host"] = host
         data: dict[str, Any] = {}
         url = parse.urljoin(f"https://{host}", endpoint)
-        LOG.debug(f"Async request: {method} {url}")
-        # LOG.debug(f"Headers: {kwargs['headers']}")
+        if self.log_traces:
+            LOG.debug(f"RAW Headers: {kwargs['headers']}")
+            LOG.debug(f"RAW Async request: {method} {url}")
         async with self.session.request(method, url, **kwargs) as resp:
             if "application/json" in resp.headers.get("content-type", ""):
                 try:
@@ -369,9 +380,8 @@ class API:
                     data = {"error": message}
             else:
                 data = {"message": await resp.text()}
-            LOG.debug(f"Returned data: {data}")
-
-            # LOG.debug("Data received from /%s: %s", endpoint, data)
+            if self.log_traces:
+                LOG.debug("RAW Data received from /%s: %s", endpoint, data)
             resp.raise_for_status()
         return data
 
@@ -547,7 +557,7 @@ class API:
 
     async def get_websocket_params(self) -> None:
         uri = parse.urlparse(self.ws_url)
-        LOG.debug(f"Getting websocket params from {self.ws_url} using {self.ws_token}")
+        LOG.debug("Getting websocket params")
         resp: dict[str, Any] = await self.async_request(
             "post",
             f"{uri.path}negotiate?{uri.query}",
